package App::Notes;
{
  $App::Notes::VERSION = '0.007';
}

# ABSTRACT: Simple. Git-based. Notes.

1;



__END__
=pod

=head1 NAME

App::Notes - Simple. Git-based. Notes.

=head1 VERSION

version 0.007

=head1 SYNOPSIS

Check out L<notes> for more info.

=head1 AUTHORS

=over 4

=item *

William Wolf <throughnothing@gmail.com>

=item *

Naveed Massjouni <naveedm9@gmail.com>

=back

=head1 COPYRIGHT AND LICENSE


William Wolf has dedicated the work to the Commons by waiving all of his
or her rights to the work worldwide under copyright law and all related or
neighboring legal rights he or she had in the work, to the extent allowable by
law.

Works under CC0 do not require attribution. When citing the work, you should
not imply endorsement by the author.

=cut

